pycocoa.octypes.objc_property_attribute_t

Package pycocoa :: Module octypes :: Class objc_property_attribute_t |
[frames] | no frames]

# Class objc_property_attribute_t

       object --+
                |
        ??._CData --+
                    |
    _ctypes.Structure --+
                        |
               c_struct_t --+
                            |
                           objc_property_attribute_t

ObjC `struct` with fields `name` and `value` (both `c_char_p`).

Instance Methods
Inherited from `c_struct_t`: `__repr__`, `__str__` Inherited from `_ctypes.Structure`: `__init__`, `__new__` Inherited from `_CData`: `__ctypes_from_outparam__`, `__hash__`, `__reduce__`, `__setstate__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
| name = `<Field type=c_char_p, ofs=0, size=8>`
| value = `<Field type=c_char_p, ofs=8, size=8>`

Properties
Inherited from `object`: `__class__`